@@ -3,8 +3,8 @@ A Canvas owns a set of Items and acts as a container for both the items
 and a constraint solver.
 """
 
-__version__ = "$Revision: 2221 $"
-# $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/canvas.py $
+__version__ = "$Revision: 2239 $"
+# $HeadURL: http://svn.devjavu.com/gaphor/gaphas/tags/gaphas-0.3.6/gaphas/canvas.py $
 
 import cairo
 from cairo import Matrix
@@ -54,6 +54,7 @@ class Canvas(object):
     
     solver = property(lambda s: s._solver)
 
+
     @observed
     def add(self, item, parent=None):
         """
@@ -91,6 +92,7 @@ class Canvas(object):
         self._dirty_items.discard(item)
         self._dirty_matrix_items.discard(item)
 
+
     def remove(self, item):
         """
         Remove item from the canvas.
@@ -125,6 +127,14 @@ class Canvas(object):
             h.connected_to = None
             h.disconnect = lambda: 0
 
+
+    def reparent(self, item, parent):
+        """
+        Set new parent for an item.
+        """
+        self._tree.reparent(item, parent)
+
+
     def get_all_items(self):
         """
         Get a list of all items.
@@ -139,7 +149,8 @@ class Canvas(object):
         [<gaphas.item.Item ...>]
         """
         return self._tree.nodes
-    
+
+
     def get_root_items(self):
         """
         Return the root items of the canvas.
@@ -157,12 +168,6 @@ class Canvas(object):
         """
         return self._tree.get_children(None)
 
-    def reparent(self, item, parent):
-        """
-        Set new parent for an item.
-        """
-        self._tree.reparent(item, parent)
-
 
     def get_parent(self, item):
         """
@@ -180,6 +185,7 @@ class Canvas(object):
         """
         return self._tree.get_parent(item)
 
+
     def get_ancestors(self, item):
         """
         See `tree.Tree.get_ancestors()`.
@@ -201,6 +207,7 @@ class Canvas(object):
         """
         return self._tree.get_ancestors(item)
 
+
     def get_children(self, item):
         """
         See `tree.Tree.get_children()`.
@@ -222,6 +229,7 @@ class Canvas(object):
         """
         return self._tree.get_children(item)
 
+
     def get_all_children(self, item):
         """
         See `tree.Tree.get_all_children()`.
@@ -243,6 +251,7 @@ class Canvas(object):
         """
         return self._tree.get_all_children(item)
 
+
     def get_connected_items(self, item):
         """
         Return a set of items that are connected to ``item``.
@@ -275,6 +284,9 @@ class Canvas(object):
                     connected_items.add((i, h))
         return connected_items
 
+
+    #{ Matrices
+
     def get_matrix_i2c(self, item, calculate=False):
         """
         Get the Item to Canvas matrix for ``item``.
@@ -284,7 +296,7 @@ class Canvas(object):
             found
         calculate:
             True will allow this function to actually calculate it,
-            in stead of raising an AttributeError when no matrix is present
+            in stead of raising an `AttributeError` when no matrix is present
             yet. Note that out-of-date matrices are not recalculated.
         """
         if item._matrix_i2c is None or calculate:
@@ -302,6 +314,8 @@ class Canvas(object):
         return item._matrix_c2i
 
 
+    #{ Update cycle
+
     @observed
     def request_update(self, item, update=True, matrix=True):
         """
@@ -328,12 +342,14 @@ class Canvas(object):
 
     reversible_method(request_update, reverse=request_update)
 
+
     def request_matrix_update(self, item):
         """
         Schedule only the matrix to be updated.
         """
         self.request_update(item, update=False, matrix=True)
 
+
     def require_update(self):
         """
         Returns ``True`` or ``False`` depending on if an update is needed.
@@ -352,6 +368,7 @@ class Canvas(object):
         """
         return bool(self._dirty_items)
 
+
     @async(single=True, priority=PRIORITY_HIGH_IDLE)
     def update(self):
         """
@@ -554,6 +571,8 @@ class Canvas(object):
         return dirty_matrix_items
 
 
+    #{ Views
+
     def register_view(self, view):
         """
         Register a view on this canvas. This method is called when setting
@@ -569,6 +588,7 @@ class Canvas(object):
         """
         self._registered_views.discard(view)
 
+
     def _update_views(self, dirty_items=(), dirty_matrix_items=(), removed_items=()):
         """
         Send an update notification to all registered views.
@@ -576,6 +596,7 @@ class Canvas(object):
         for v in self._registered_views:
             v.request_update(dirty_items, dirty_matrix_items, removed_items)
 
+
     def _obtain_cairo_context(self):
         """
         Try to obtain a Cairo context.
