@@ -2,8 +2,8 @@
 Basic items.
 """
 
-__version__ = "$Revision: 2214 $"
-# $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/item.py $
+__version__ = "$Revision: 2266 $"
+# $HeadURL: http://svn.devjavu.com/gaphor/gaphas/tags/gaphas-0.3.6/gaphas/item.py $
 
 from math import atan2
 from weakref import WeakKeyDictionary
@@ -12,7 +12,7 @@ from matrix import Matrix
 from geometry import distance_line_point, distance_rectangle_point
 from solver import solvable, WEAK, NORMAL, STRONG, VERY_STRONG
 from constraint import EqualsConstraint, LessThanConstraint
-from state import observed, reversible_pair, reversible_property, disable_dispatching
+from state import observed, reversible_method, reversible_pair, reversible_property, disable_dispatching
 
 
 class Handle(object):
@@ -446,7 +446,7 @@ class Line(Item):
 
         self._line_width = 2
         self._fuzziness = 0
-        self._orthogonal = []
+        self._orthogonal_constraints = []
         self._horizontal = False
         self._head_angle = self._tail_angle = 0
 
@@ -462,20 +462,18 @@ class Line(Item):
 
     fuzziness = reversible_property(lambda s: s._fuzziness, _set_fuzziness)
 
-    @observed
-    def _set_orthogonal(self, orthogonal):
+    def _update_orthogonal_constraints(self, orthogonal):
         """
-        >>> a = Line()
-        >>> a.orthogonal
-        False
+        Update the constraints required to maintain the orthogonal line.
+        The actual constraints attribute (``_orthogonal_constraints``) is
+        observed, so the undo system will update the contents properly
         """
         if not self.canvas:
-            self._orthogonal = orthogonal and [ None ] or []
+            self._orthogonal_constraints = orthogonal and [ None ] or []
             return
 
-        for c in self._orthogonal:
+        for c in self._orthogonal_constraints:
             self.canvas.solver.remove_constraint(c)
-            self._orthogonal = []
 
         if not orthogonal:
             return
@@ -485,7 +483,7 @@ class Line(Item):
             self.split_segment(0)
         eq = EqualsConstraint #lambda a, b: a - b
         add = self.canvas.solver.add_constraint
-        cons = self._orthogonal
+        cons = []
         rest = self._horizontal and 1 or 0
         for pos, (h0, h1) in enumerate(zip(h, h[1:])):
             if pos % 2 == rest: # odd
@@ -494,11 +492,36 @@ class Line(Item):
                 cons.append(add(eq(a=h0.y, b=h1.y)))
             self.canvas.solver.request_resolve(h1.x)
             self.canvas.solver.request_resolve(h1.y)
+        self._set_orthogonal_constraints(cons)
         self.request_update()
 
-    orthogonal = reversible_property(lambda s: bool(s._orthogonal), _set_orthogonal)
+    @observed
+    def _set_orthogonal_constraints(self, orthogonal_constraints):
+        """
+        Setter for the constraints maintained. Required for the undo system.
+        """
+        self._orthogonal_constraints = orthogonal_constraints
+
+    reversible_property(lambda s: s._orthogonal_constraints, _set_orthogonal_constraints)
 
     @observed
+    def _set_orthogonal(self, orthogonal):
+        """
+        >>> a = Line()
+        >>> a.orthogonal
+        False
+        """
+        self._update_orthogonal_constraints(orthogonal)
+
+    orthogonal = reversible_property(lambda s: bool(s._orthogonal_constraints), _set_orthogonal)
+
+    @observed
+    def _inner_set_horizontal(self, horizontal):
+        self._horizontal = horizontal
+
+    reversible_method(_inner_set_horizontal, _inner_set_horizontal,
+                      {'horizontal': lambda horizontal: not horizontal })
+
     def _set_horizontal(self, horizontal):
         """
         >>> line = Line()
@@ -508,8 +531,8 @@ class Line(Item):
         >>> line.horizontal
         False
         """
-        self._horizontal = horizontal
-        self._set_orthogonal(self._orthogonal)
+        self._inner_set_horizontal(horizontal)
+        self._update_orthogonal_constraints(self._orthogonal_constraints)
 
     horizontal = reversible_property(lambda s: s._horizontal, _set_horizontal)
 
@@ -518,14 +541,14 @@ class Line(Item):
         Setup constraints. In this case orthogonal.
         """
         super(Line, self).setup_canvas()
-        self.orthogonal = self.orthogonal
+        self._update_orthogonal_constraints(self.orthogonal)
 
     def teardown_canvas(self):
         """
         Remove constraints created in setup_canvas().
         """
         super(Line, self).teardown_canvas()
-        for c in self._orthogonal:
+        for c in self._orthogonal_constraints:
             self.canvas.solver.remove_constraint(c)
 
     @observed
@@ -585,7 +608,7 @@ class Line(Item):
                 do_split(segment + 1, parts - 1)
         do_split(segment, parts)
         # Force orthogonal constraints to be recreated
-        self.orthogonal = self.orthogonal
+        self._update_orthogonal_constraints(self.orthogonal)
         return self._handles[segment+1:segment+parts]
 
     def merge_segment(self, segment, parts=2):
@@ -629,7 +652,7 @@ class Line(Item):
             self.merge_segment(segment, parts - 1)
         else:
             # Force orthogonal constraints to be recreated
-            self.orthogonal = self.orthogonal
+            self._update_orthogonal_constraints(self.orthogonal)
         return deleted_handles
 
 
@@ -731,9 +754,6 @@ class Line(Item):
 
 __test__ = {
     'Line._set_orthogonal': Line._set_orthogonal,
-    'Line._set_horizontal': Line._set_horizontal,
-    'Line.split_segment': Line.split_segment,
-    'Line.merge_segment': Line.merge_segment,
     }
 
 
