@@ -21,8 +21,8 @@ Maybe even:
     (context.view = view; context.grab() to grab, context.ungrab() to ungrab)
 """
 
-__version__ = "$Revision: 2173 $"
-# $HeadURL: https://svn.devjavu.com/gaphor/gaphas/trunk/gaphas/tool.py $
+__version__ = "$Revision: 2234 $"
+# $HeadURL: http://svn.devjavu.com/gaphor/gaphas/tags/gaphas-0.3.6/gaphas/tool.py $
 
 import cairo
 import gtk
@@ -610,6 +610,9 @@ class PlacementTool(Tool):
         view = context.view
         canvas = view.canvas
         new_item = self._create_item(context, event.x, event.y)
+        # Enforce matrix update, as a good matrix is required for the handle
+        # positioning:
+        canvas.get_matrix_i2c(new_item, calculate=True)
         self._handle_tool.grab_handle(new_item,
                                       new_item.handles()[self._handle_index])
         self._new_item = new_item
